@@ -517,7 +517,7 @@ c***********************************************************************
       dlam=hipr1(15)
       aph=12.0d0*3.1415926d0/(33.0d0-2.0d0*af)/dlog(amt2/dlam**2)
  
-      call parton(f,x1,x2,amt2)
+      call jmparton(f,x1,x2,amt2)
  
       gqq=4.0d0*( cosh(y1-y2)+hipr1(7)**2/amt2 
      &  )/(1.d0+cosh(y1-y2))/9.0d0
@@ -553,7 +553,7 @@ c...Provide function for the calculation of direct photon.
       aph=12.0d0*3.1415926d0/(33.0d0-2.0d0*af)/dlog(pt2/dlam**2)
       aphem=1.0d0/137.0d0
  
-      call parton(f,x1,x2,pt2)
+      call jmparton(f,x1,x2,pt2)
  
       g11=-(u**2+1.0d0)/u/3.0d0*f(1,7)*(
      $  4.0d0*f(2,1)+4.0d0*f(2,2)+f(2,3)+f(2,4)+f(2,5)+f(2,6)
@@ -591,7 +591,7 @@ c...Provide function for the calculation of QCD processes.
       aph=12.0d0*3.1415926d0/(33.0d0-2.0d0*af)/dlog(pt2/dlam**2)
  
 c....Structure function
-      call parton(f,x1,x2,pt2)
+      call jmparton(f,x1,x2,pt2)
  
 c...q q'-> qq' t-channel gluon exchange
 
@@ -697,7 +697,7 @@ c...gg->gg.
 
 c***********************************************************************
 
-      subroutine parton(f,x1,x2,qq)
+      subroutine jmparton(f,x1,x2,qq)
 
 c...Calculate the structure function with nuclear effect.
       implicit double precision(a-h, o-z)
