@@ -1,4 +1,4 @@
-      subroutine cphitsOut(id,  n, a)
+      subroutine cphitsOut(id, pj, ia, iz,  n, a)
 c       **** note  param00.inc by phits dose not accept implicit none
 c            a-h,o-z: double.  i-m; integer
 c            New variables here must be explicitly declared
@@ -9,6 +9,9 @@ c            without exception
 #include "Zptcl.h"
       integer:: nnn, nomp
       include "JQMD/param00.inc"
+      record /ptcl/ pj  ! input. projectile 
+      integer,intent(in):: ia ! target A
+      integer,intent(in):: iz ! target Z 
       integer,intent(in):: id ! 1--> output before nevap; 2-->output after nevap
       integer,intent(out)::n  ! total number of ptcls 
       record /ptcl/ a(*)       !   a(n). each ptcl property
@@ -232,8 +235,9 @@ c///////////////
       write(0,*) ' length  of cid=',len(cid), ' ncl=',ncl
 
       write(0,'(a,a)') ' id=', cid
+
       write(0,*)
-     * '  #  code subc chg      Px       Py      Pz       KE (MeV)' 
+     * '# code subc chg    Px       Py      Pz       KE (MeV)' 
       do i = 1, ncl
          kfcode=jcl(7,i)
 c//////////////
