@@ -92,6 +92,7 @@ c     ********************* tested 91.08.09 ******************k.k*******
          real*8 u
          integer n
          real*8 ua(n)
+         real(8)::u1(1)
 c
          integer iseed(25), ir1(2), ir2, jold, jnew
          logical first2/.true./
@@ -99,13 +100,18 @@ c
          save jsw, first2
 c
          if(jsw .eq. 1) then
-             call rnd1u(u, 1)
+!!             call rnd1u(u, 1)  ! jaxa complains at execution time
+                              ! since u is not array
+             call rnd1u(u1, 1)
+             u = u1(1)
          elseif(jsw .eq. 2) then
              if(first2) then
                 first2=.false.
                 call rnd2ix(31415926)
              endif
-             call rnd2u(u, 1)
+!!             call rnd2u(u, 1)
+             call rnd2u(u1, 1)
+             u = u1(1)
          else
              write(*,*) ' switch value error=',jsw, ' in rndc '
              stop 9999
