@@ -15,6 +15,9 @@ c
          write(ErrorOut, '(a)') msg(1:klena(msg))
       endif
       if(needrtn .eq. 0)  then
+#if defined (PCLinuxIFC64) || (PCLinuxIFC)
+         call TRACEBACKQQ()
+#endif
          call cbackTrace(dummy)
       endif
       end
