@@ -18,7 +18,9 @@ c
              gb.p(3)=p.fm.p(3)/p.mass
              gb.p(4)=max(p.fm.p(4)/p.mass, 1.d0)
          else
-             write(*, *) ' mass=', p.mass, ' invalid to cgetlf'
+             write(0, *) ' mass=', p.mass, ' invalid to cgetlf'
+             call cbackTrace(p)
              stop 9999
          endif
         end   
+      
