@@ -423,9 +423,9 @@ c
          call cgpid(code, id)
          write(msg, *) ' ---------code=',p(i).code, ' id=', id
          call cerrorMsg(msg, 1)
-         write(msg, *) ' 4 momentum=',(p(i).fm.p(j),j=1, 4), ' mass=',
+         write(0, *) ' 4 momentum=',(p(i).fm.p(j),j=1, 4), ' mass=',
      *               p(i).mass
-         call cerrorMsg(msg, 1)
+c         call cerrorMsg(msg, 1)
          write(msg, *) ' charge=', p(i).charge, ' subcode=',
      *    p(i).subcode
          call cerrorMsg(msg, 1)
