@@ -134,6 +134,13 @@ c             drop small xxx
 
 
       subroutine chAcolx(pj, ia, iz, a, ntp)
+!      if only.. is omitted "both" in here and cheavyInt.f
+!      at link time of large program, a message something like
+!      TargetXs for x86-64 is missing
+!      comes out and stops. 
+#if !defined (MacIFC)
+      use modXsecMedia
+#endif
       implicit none
 #include  "Zcondc.h"
 #include  "Zcode.h"
@@ -149,6 +156,10 @@ c
       record /ptcl/ a(*)  !  output. produced ptcls
       integer ntp   ! number of produced ptcls
 
+#if defined (MacIFC)
+#include "Zworkaround.h"
+#endif
+
 
 c
 cc      if(IntModel .eq. 'int1') then
@@ -166,7 +177,9 @@ c            chAcol argment in future ?
       elseif( ActiveMdl .eq. 'qgsjet2') then
          call cQGSjet(pj, ia, iz, a, ntp)
       elseif( ActiveMdl == 'epos') then
-         call ceposGenOneEvent(a, ntp)
+         call ceposGenOneEvent(pj, ia, iz, a, ntp)
+      elseif( ActiveMdl == 'sibyll') then
+         call csibyllevent(pj, ia, iz, a, ntp)
       elseif( ActiveMdl .eq. 'fritiof1.6' .or. 
      *        ActiveMdl .eq. 'nucrin') then
             call chALund(pj, ia, iz, a, ntp)
