@@ -141,7 +141,8 @@ c   &&&&&&&&&&&&&&&&
          code = kphi
          subcode = 0
          chg = 0
-      elseif( kfabs .ge. 1000010020 .and. kfabs .le. 1000922350 ) then
+c      elseif( kfabs .ge. 1000010020 .and. kfabs .le. 1000922350 ) then  ! 2013/4/12
+      elseif( kfabs .ge. 1000000020 .and. kfabs .le. 1000922350 ) then  ! 2n system
 c           nucleus is  10LZZZAAAI where L=0 (if not containing strangeness)
 c           ZZZ is 3 digits of charge, AAA 3digits of mass no. I=0 for
 c           gound state; so for our case, 1000010020 is minimum for deuteron
@@ -154,12 +155,17 @@ c           and 1000922350 is max for U(235)
             subcode =( (kfabs/10)*10-(kfabs/10000)*10000 )/10
             chg =( (kfabs/10000)*10000 - (kfabs/1000000)*1000000 )
      *        /10000     
+            if( kfabs < 1000010020 ) then  ! charge 0               
+               code = krare
+            endif
          endif
       else
          code = krare
+      endif
+      if( code == krare ) then
          write(msg, *) 'not implemented kf code=', kf
          call cerrorMsg(msg, 1)
-         call cerrorMsg('we neglect this particle',1)
+         call cerrorMsg('we may neglect this particle',1)
       endif
       end
 
