@@ -9,13 +9,13 @@ c
       record /ptcl/pj   !input projectile particle
       real(8),intent(in)::  A     ! input. effective target mass number
       real(8),intent(in)::  Z     ! input. effective target charge number
-      real(8),intent(out):: xs    ! output. in mb. total xsection. 
+      real(8),intent(out):: xs    ! output. in mb. inelastic xs.
 
       real(8):: gamma
       record /ptcl/ target
       integer:: tcharge
       real(8):: pjA, pjZ
-      real(8) cinelCosByPdg
+
 
       if( A == 1.0 .and. pj.code == kgnuc  ) then ! target is p/n, pj is heavy ion
                ! we use proj. rest system ;  if not, inside cinelx0 
@@ -32,18 +32,14 @@ c
             target.fm.p(4) = gamma*masp
          endif
          call cinelx0(target, pjA, pjZ, xs)   ! target is now proj. pjA is target
-         xs = xs / cinelCosbyPdg(pjA)
+
       else
          call cinelx0(pj, A, Z,  xs)      
-         if( abs(A-1.0) > 0.1 ) then  ! target is Nucleus
-            if( pj.code /= kgnuc ) then  ! incident is not heavy ion
-               xs = xs / cinelCosbyPdg(A)
-            endif
-         endif
       endif
       end
 
       subroutine cinelx0(pj, A, Z, xs)
+      use modcosXsec  ! refer only nIsDiff
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
@@ -53,11 +49,17 @@ c
       real(8),intent(in)::  Z     ! input. effective target charge number
       real(8),intent(out):: xs          ! output. in mb. total xsection. 
 
+
       real(8) p
+      real(8),external:: cPDGsigmaInepA
+      real(8),save:: Aprev=-100., norm
+      real(8):: xs200, xs200A
 
 
       real(8)::shp, shn
+
       if( pj.fm.p(4) .le. pj.mass) then
+         p =0.
          if(pj.code .eq. knuc .and. pj.subcode .eq. antip) then
             xs = largexs
          elseif(pj.code .eq. kelec .and. pj.charge .eq. 1) then
@@ -69,19 +71,35 @@ c
          p = sqrt(pj.fm.p(4)**2 - pj.mass**2)
          if(pj.code .eq. knuc) then
             if(pj.charge .eq. 1) then
-               call cppInelaXs(p, shp)
-               if(A .gt. 1.) then
-                  call cnpInelaXs(p, shn)
-                  shp = (shp + shn)/2.0
+               if( A == 1.0 ) then
+                  if( Z == 1.0 ) then
+                     call cppInelaXs(p, xs)
+                  elseif( Z == 0.) then
+                     call cnpInelaXs(p, xs)
+                  else
+                     write(0,*) 'A,Z=',A,Z, 'for p pj'
+                     write(0,*) 'in cinelx; invalid'
+                     stop
+                  endif
+               elseif(A > 1.) then
+                  call cppInelaXs(p, shp)
+                  if( nIsDiff ) then 
+                     call cnpInelaXs(p, shn)
+                     shp = (shp + shn)/2.0
+                  endif
                   call cxp2xAXsec(A, shp, xs)
                else
-                  xs = shp
+                  write(0,*) ' A,Z for cinelx invalid'
+                  write(0,*) ' pj is p '
+                  stop
                endif
             elseif(pj.charge .eq. -1) then
                call cpbarpInelaXs(p, shp)
                if( A .gt. 1.) then
-                  call cnbarpInelaXs(p, shn)
-                  shp = (shp + shn)/2.
+                  if(nIsDiff) then
+                     call cnbarpInelaXs(p, shn)
+                     shp = (shp + shn)/2.
+                  endif
                   call cxp2xAXsec(A, shp, xs)
                else
                   xs = shp
@@ -119,19 +137,30 @@ c               neutron
             endif
          elseif(pj.code .eq. kkaon) then
             if(pj.charge .eq. 1) then
-               call ckppInelaXs(p, shp)
-               if(A .gt. 1.) then
-                  call ckpnInelaXs(p, shn)
-                  shp = (shp + shn)/2.0
+               if(A == 1.0) then
+                  if( Z==1.0) then
+                     call ckppInelaXs(p, xs)
+                  else
+                     call ckpnInelaXs(p, xs)
+                  endif
+               elseif(A .gt. 1.) then
+                  call ckppInelaXs(p, shp)
+                  if( nIsDiff ) then
+                     call ckpnInelaXs(p, shn)
+                     shp = (shp + shn)/2.0
+                  endif
                   call cxp2xAXsec(A, shp, xs)               
                else
-                  xs = shp
+                  write(0,*) 'A,Z=',A,Z, ' invalid for cinel.Kaon'
+                  stop
                endif
             elseif(pj.charge .eq. -1) then
                call ckmpInelaXs(p, shp)
                if(A .gt. 1.) then
-                  call ckmnInelaXs(p, shn)
-                  shp = (shp + shn)/2.
+                  if( nIsDiff ) then
+                     call ckmnInelaXs(p, shn)
+                     shp = (shp + shn)/2.
+                  endif
                   call cxp2xAXsec(A, shp, xs)               
                else
                   xs = shp
@@ -139,8 +168,8 @@ c               neutron
             else
 c             k0; don't worry so much 
                call ckmpInelaXs(p, shp)
-               call ckmnInelaXs(p, shn)
-               shp = (shp+ shn)/2.
+!!               call ckmnInelaXs(p, shn)
+!!               shp = (shp+ shn)/2.
                if(A .gt. 1.) then
                   call cxp2xAXsec(A, shp, xs)               
                else
@@ -175,11 +204,27 @@ c          use pion
             call cxp2xAXsec(A, shp, xs)               
          endif
       endif
+!!!       normalize to pdg at 200 GeV. norm const is
+!!!       applied to other collisions 
+      if(A > 1. .and. A /=  Aprev ) then
+         call cppInelaXs(200.d0, xs200)
+         call cxp2xAXsec(A, xs200, xs200A)
+!!         write(0,*) ' xs200A=',xs200A, ' pgd=',  cPDGsigmaInepA(A)
+         norm =  cPDGsigmaInepA(A) /xs200A
+!!         write(0,*) ' norm=', norm
+         Aprev = A
+      elseif( A == 1.)  then
+         norm = 1.
+         Aprev = A
+      endif
+      xs = xs*norm
+
       end
       function cinelCosByPdg(A)  result(ratio)
 !             sigmaInela(pA)cosmos/sigmaInela(pA)PDG
 !        @ 200 GeV.  SigmaInela by cosmos is the one
-!             obtained by cinelx0     
+!             obtained by cinelx0  before  
+!             cxp2xAXsec  included cxAbyxpXsec.
 !       
       real(8),intent(in):: A
       real(8):: ratio
