@@ -4,7 +4,7 @@ c        pi-n total xsection , elastic xs
       real*8 p  ! input.  momentum of n. in GeV
       real*8 xs     ! output. total np cross section in mb
       call cpippTotXs(p, xs)
-      end
+      end      subroutine cpimnTotXs
 c         
       subroutine cpimnElaXs(p, xs)
 c           pi+ p elastic cross section in mb
@@ -12,7 +12,7 @@ c           pi+ p elastic cross section in mb
       real*8 p ! input.  momentum of n in GeV
       real*8  xs   ! output np elastic xs. mb.
       call cpippElaXs(p, xs)
-       end
+      end      subroutine cpimnElaXs
       subroutine cpimnInelaXs(p, xs)
       implicit none
       real(8),intent(in)::p
@@ -20,4 +20,5 @@ c           pi+ p elastic cross section in mb
 
       real(8)::txs, exs
       call cpippInelaXs(p, xs)
-      end
+      end      subroutine cpimnInelaXs
+
