@@ -4,7 +4,7 @@ c        pi+n total xsection , elastic xs
       real*8 p  ! input.  momentum of n. in GeV
       real*8 xs     ! output. total np cross section in mb
       call cpimpTotXs(p, xs)
-      end
+      end      subroutine cpipnTotXs
 c         
       subroutine cpipnElaXs(p, xs)
 c           pi+ p elastic cross section in mb
@@ -12,10 +12,11 @@ c           pi+ p elastic cross section in mb
       real*8 p ! input.  momentum of n in GeV
       real*8  xs   ! output np elastic xs. mb.
       call cpimpElaXs(p, xs)
-       end
+      end      subroutine cpipnElaXs
       subroutine cpipnInelaXs(p, xs)
       implicit none
       real(8),intent(in)::p
       real(8),intent(out)::xs
       call cpimpInelaXs(p, xs)
-      end
+      end subroutine cpipnInelaXs
+
