@@ -1,4 +1,10 @@
       subroutine cGetXsec(model, pj, media, xs, mfp)
+! @JAXA, xs=0 leads to 0-divide error and after 10 repeats
+! stop is made.  At other systems, 0 divide
+! in this case has no bad effect. 
+! So change is made as follows.
+!    xs == smallxs is made to xs <= smallxs.
+!
 !         get hadronic interaction cross-section for
 !    given interaction model,  projectile and medium.
 !    The media information must have been set via
@@ -29,7 +35,7 @@
       elseif( pj.code == kneue .or. pj.code == kneumu ) then
          xs = smallxs
          media%xs = xs
-         mfp  =0.
+         mfp  = largexs
          return                 ! *******************
       endif
       select case(model)
@@ -52,9 +58,12 @@
         case default
          call cxsOther( pj, media)
       end select
+      if(media%xs < smallxs) then
+         media%xs = smallxs
+      endif
       if( media%xs /= smallxs .and. media%xs /= largexs) then
          mfp = 1.0d0/( media%mbtoPkgrm * media%xs)
-      elseif( media%xs == smallxs ) then
+      elseif( media%xs <= smallxs ) then
          mfp = largexs
       else
          mfp = 0.
@@ -76,7 +85,6 @@
 
       integer i
       real(8):: sumns,  xs
-
       sumns=0. 
       do i = 1, media%noOfElem
          if(pj.code >= kpion .and. pj.code <= knuc ) then
@@ -92,6 +100,9 @@
          else
             call cinelx(pj, media%elem(i)%A,  media%elem(i)%Z, xs)
          endif
+         if( xs <  smallxs ) then
+            xs = smallxs
+         endif
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
             exit
@@ -140,7 +151,7 @@ ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
 !               call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
 !            endif
          endif
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -169,12 +180,12 @@ ccc            xs = xs + elaxs  ! phits elaxs for heavy is 0
             if( pj.fm.p(4) .lt.  4.1d0 ) then  ! Et is better than Ek
                call ctotx(pj, media%elem(i)%A,  xs)
 c//////////////////
-               if( pj.code == 6 .and. pj.charge == -1  .and.
-     *              (pj.fm.p(4)- pj.mass) < 1d-3 ) then
-                  write(0,*) '********* ', pj.fm.p(4)-pj.mass,
-     *             xs
-                  write(0,*) ' largexs=',largexs
-               endif
+c               if( pj.code == 6 .and. pj.charge == -1  .and.
+c     *              (pj.fm.p(4)- pj.mass) < 1d-3 ) then
+c                  write(0,*) '********* ', pj.fm.p(4)-pj.mass,
+c     *             xs
+c                  write(0,*) ' largexs=',largexs
+c               endif
 c///////////////////
             else
                call cinelx(pj, media%elem(i)%A,  media%elem(i)%Z, xs)
@@ -182,7 +193,7 @@ c///////////////////
          else
             call cinelx(pj, media%elem(i)%A, media%elem(i)%Z, xs)
          endif
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -224,7 +235,7 @@ c///////////////////
             call cinelx(pj, tga, tgz, xs)
          endif
 
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -268,7 +279,7 @@ c///////////////////
          tg.fm.p(1:3) = 0.
          tg.fm.p(4) = tg.mass
          call ceposIniOneEvent(pj, tg, xs)
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -315,7 +326,7 @@ c///////////////////
             tg.subcode = 0  !sibyll can do for almost Air target only. 
          endif
          call csibyllXs(pj, tg, xs)
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -348,7 +359,7 @@ c///////////////////
          else
             call cinelx(pj, tga, tgz, xs)
          endif
-         if( xs == smallxs .or. xs == largexs ) then 
+         if( xs <= smallxs .or. xs == largexs ) then 
             sumns = xs
             exit
          else
@@ -403,7 +414,7 @@ c         *********************************
 c//////////////
 c         write(0,*) 'in othert;  xs=',xs, i,  media%noOfElem
 c////////////
-         if( xs == smallxs .or. xs == largexs ) then
+         if( xs <= smallxs .or. xs == largexs ) then
             sumns = xs
             exit
          else
@@ -571,6 +582,9 @@ c
       sumns = 0.
       do i = 1, media%noOfElem
          call cgpXsec(media%elem(i)%A, pj.fm.p(4), xs)
+         if( xs < smallxs ) then
+            xs = smallxs
+         endif
          if( xs == smallxs .or. xs == largexs ) then
             sumns = xs
             exit
