@@ -61,7 +61,8 @@ c
          write(0,*) ' i=', i, ' InteErg2(i)=',
      *   InteErg2(i)
       enddo
-      stop 123456
+!!      stop 123456
+      stop 23456    !! jaxa length should be <=5
  15   continue
 
       if( aPtcl.code == knuc .and.  aPtcl.subcode == antip ) then
