@@ -58,21 +58,6 @@ c           make it  to the unit vector    vector:  Bef  1--->2  Moved
       endif
          
       if(cross) then
-
-c////////////////////
-c          there is small diff. between unitv and TrackBefMove.vec
-c      so  it may be neglected. though we use unitv.
-c     
-c         if(MoveStat ==  ToBeObserved  .and. 
-c     *         MovedTrack.p.code   == 2 ) then
-c            write(*, *) ' unitv=',unitv.x, unitv.y, unitv.z
-c            write(*, *) ' dir  =',TrackBefMove.vec.w.x,
-c     *                         TrackBefMove.vec.w.y,
-c     *                         TrackBefMove.vec.w.z
-c         endif
-c//////////////////
-
-
          IntInfArray(ProcessNo).length = leng
          IntInfArray(ProcessNo).thickness = clen2thick(
      *     TrackBefMove.pos.radiallen - Eradius,
@@ -80,7 +65,7 @@ c//////////////////
 
          call cmoveStreight(leng, unitv)
          MovedTrack.vec.w = unitv 
-         call cresetMom(MovedTrack)
+
 c                      bef. replace, w for low energy electron
 c                      may be largely scattered and even
 c                      backward at the path end.
@@ -103,14 +88,20 @@ c            MovedTrack.where = NoOfSites+1
             endif
          endif
 
-         if(MovedTrack.p.charge .ne. 0) then
-            call cqElossRate(dedt, dedtF) ! get de/dx computed previously
+         if(MovedTrack.p.charge /= 0) then 
+c              sinc path has been cut, recalculate Energy loss
+                ! get de/dx computed previously
+            call cqElossRate(dedt, dedtF)
             EnergyLoss = dedt * IntInfArray(ProcessNo).thickness
             MovedTrack.p.fm.p(4) = TrackBefMove.p.fm.p(4)-EnergyLoss
-            if(MovedTrack.p.fm.p(4) .lt.  MovedTrack.p.mass ) then
-               MovedTrack.p.fm.p(4) = MovedTrack.p.mass 
-               EnergyLoss =  TrackBefMove.p.fm.p(4)- MovedTrack.p.mass 
-            endif
+            call cresetMombyEdir(MovedTrack) 
+!              reset Energyloss since E in MovedTrack might have been
+!              reset to mass if energyloss was too big.
+            EnergyLoss = TrackBefMove.p.fm.p(4)- MovedTrack.p.fm.p(4)
+         else
+!             charge = 0
+           ! nothing to   do. even path is cut, momenutum etc
+!            dose not change.
          endif
       else
          nextwhere = loc
