@@ -171,14 +171,7 @@ cc         call epReadMediaForMuon  !////////////
       end
       subroutine  epReadMediaForMuon
 #include  "Zcode.h"
-c  c#include  "Zptcl.h"
-!! #include  "Zevhnp.h"
-!! #include  "Zevhnv.h"
-!! #include  "Zmass.h"
-!! #include  "Zmanager.h"
-!! #include  "Zmanagerp.h"
-!! #include  "Ztrackp.h"
-#include  "ZepTrackv.h"
+#include  "Zptcl.h"
       
       include  "Zprivate.h"
       integer icon
