@@ -8,8 +8,8 @@ c       main program of cosmos
 #include "ZcosmosExt.h"
 #include "jamextrn.inc"
 c///////////
-         call mydummy
-         call myPhitsDummy
+c         call mydummy
+c         call myPhitsDummy
 c/////////////
          call cmanager   ! call Manager for Cosmos Simulation
       end
