@@ -14,16 +14,15 @@ c	(->  ---------------------------------------------
                       !        are most promissing models that fit the observed 
                       !       data (muons and gamma rays) for which the primary is well known by
                       !       BESS and AMS observations ($<$ 100 GeV).
+        character*64  XsecModel !1 Xsection model description.  Noarmally should not be given.
+                      ! Defaul is to use the hadronic xsection given by each active model
+                      ! fixed by IntModel. However, for some experimental purposes,
+                      ! one may employ x-section by other interaction model.
+                      !      e.g.
+                      !     IntModel ='"phits" 2 "dpmjet" '
+                      !     XsecModel='"Phits" 2 "dpmjet" 80 "qgsjet2"'
+                      !  is one example. Default is blank and is replaced by IntModel
 
-c              next is old def.
-c        character*16  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
-c                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
-c                       ! at low energies. (See, Elund?).
-c                       !  If 'inclusive', an inclusive treatment is employed as given in Contrib/Inclusive.
-c                       !  To make this work actually, INCLUSIVE in cosmos/Zcondc.h must be given a value of 1
-c                       !  when making the cosmos library.  At execution time, InclusiveFile must be given
-c                       !  the path to the xdist.d file. (normally in Contrib/Inclusive/xdist.d)
-c                       !  The treatmen is one dimesional. May be used for neutrino calculations.
         character*100 InclusiveFile !2 The path to the inclusive data file, xdist.d. Default is
                        !   "../Contrib/Inclusive/xdist.d"
         real*8 SucPw   !2  In the 2nd, 3rd,.. collision of a nucleon inside a nucleus, the collision is 
@@ -45,6 +44,26 @@ c                       !  The treatmen is one dimesional. May be used for neutr
                        !  message; both on ErrorOut. LundPara(5) =0 $\Rightarrow$    All kaons collisions
                        !  are treated as pi- in Fritiof, else they are treated by adhoc model as they are.
 !                 below: Obsolete
+        integer TotXSopt !2 option for total x-section.  1.  PDG  3. TOTEM (COMPETE fitting)
+                         !   2. between 1 and 3.  (1 is lowest 3 is highest X-sec.) 
+                         !   Diff. becomes gradually seen at  roots > few x 10^2 GeV
+                         !   This for p-p case. Default is 2.
+
+                         !   For other collision types, 1 is used.
+                         !   If the current interaction model supplies the inelastic 
+                         !   cross-section,  it is used without referring to this. 
+                         !    However, see  XsecModel.
+        integer SxAbySxpOpt !2  For nucleus target with mass # A, cross section is converted
+                        !    from the one for proton target.  This option fixes which
+                       !   SxA/sxp table is used. This is used when the current interaction
+                       !   model dose not supply the cross-section. (See XsecModel too).
+                       !   1.  use table derived from  QGSJET-II-04  (default)
+                       !   2.  use table derived from dpjmet3
+                       !   3.  use table dervied from EPOS  (but can be used for A<=64).
+                       !        (as of 2013/Jun).
+                       !   However, for small cross-sections (such as gamma-A, nu-A, old
+                       !   cxp2xA routine is used).
+
         real*8  Cepic0  !2  Obsolete 
         real*8  Cekaon  !2  Obsolete
         integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.\newline
@@ -67,18 +86,22 @@ c              old def
          integer:: DoNPadjust !2 0(Default):  0--> original is used
                     ! 1--> do adustement of  # of n,p  for phits model
                     !  when projectile is  p or n and target A > 10.
-
+         integer:: dpmRareDecay !2 1(Default):  Rare ptcls in dpmjet3 is
+                     ! forced to decay. (see cdpmRareDecay in cdpmjet3.f)
+                     ! 0--> not decayed
 c	<-)     -----------------------------
 c            next are not input parameters.
         integer nmdls
-        parameter (nmdls = 11)
+        parameter (nmdls = 12)
         character*16 RegMdls(nmdls)
         real*8 smallxs, largexs
         parameter (smallxs=1.d-10, largexs=1.d10)
 
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
-     *         LundPara(10), SucInt, DoNPadjust
+     *         LundPara(10), SucInt, DoNPadjust, dpmRareDecay,
+     *         TotXSopt, SxAbySxpOpt
 !!     *         LundPara(10), SucInt
-        common /Zevhnc/RegMdls, InclusiveFile, IntModel
+        common /Zevhnc/RegMdls, InclusiveFile, IntModel, XsecModel
+
 
